@@ -2,14 +2,14 @@
 from ut_dic.dic import Dic
 
 from collections.abc import Callable
-from typing import Any, Dict
+from typing import Any, Dict, Union
 
 TyArr = list[Any]
 TyCallable = Callable[..., Any]
 TyDic = dict[Any, Any]
 TyStr = str
 TyArr_Str = str | TyArr
-TyDnDoC = Dict[Any, 'TyDnDoC' | TyCallable]
+TyDnDoC = Dict[Any, Union['TyDnDoC', Callable[..., Any]]]
 
 TnStr = None | TyStr
 TnArr_Str = None | TyArr_Str
